pygeodesy.frechet.FrechetFlatLocal

Package pygeodesy :: Module frechet :: Class FrechetFlatLocal |
[frames] | no frames]

# Class FrechetFlatLocal

      object --+
               |
    named._Named --+
                   |
             Frechet --+
                       |
    _FrechetMeterRadians --+
                           |
                          FrechetFlatLocal

Known Subclasses:
  - FrechetHubeny

Compute the `Frechet` distance with function pygeodesy.flatLocal_/pygeodesy.hubeny.

Instance Methods
__init__(self, point1s, **fraction_name__datum_scaled_wrap) New FrechetFlatLocal/FrechetHubeny calculator/interpolator. |
discrete(self, point2s, fraction=None, recursive=False) Compute the `forward, discrete Fréchet` distance. |
Inherited from `Frechet`: `distance`, `point`, `points_`, `points_fraction` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Frechet`: `adjust`, `datum`, `fraction`, `kwds`, `units`, `wrap` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, point1s, **fraction_name__datum_scaled_wrap) (Constructor) |
New FrechetFlatLocal/FrechetHubeny calculator/interpolator. Arguments: `fraction_name__datum_scaled_wrap` - Optional `fraction=None` and `name=NN` and keyword arguments for function pygeodesy.flatLocal. Raises: `FrechetError` - Insufficient number of `point1s` or an invalid `point1`, `fraction` or `units`. Overrides: object.__init__ See Also: Frechet.__init__ for details about `point1s`, `fraction`, `name` and other exceptions. Note: The distance `units` are `radians squared`, not `radians`.

### discrete (self, point2s, fraction=None, recursive=False) |
Compute the `forward, discrete Fréchet` distance. Arguments: `point2s` - Second set of points (`LatLon`[], Numpy2LatLon[], Tuple2LatLon[] or `other`[]). `fraction` - Index fraction (`float` in EPS..EPS1) to interpolate intermediate `point2s` or use `None`, `0` or `1` for no intermediate `point2s` and no fractional indices. `recursive` - Use `True` for backward compatibility (`bool`) or with fractional indices. Returns: A Frechet6Tuple`(fd, fi1, fi2, r, n, units)`. Raises: `FrechetError` - Insufficient number of `point2s` or an invalid `point2` or `fraction` or `non-recursive` and fractional. `RecursionError` - Recursion depth exceeded, see sys.getrecursionlimit, only with `recursive=True`. Overrides: Frechet.discrete